@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -21,16 +22,20 @@
 #include "filters.h"
 namespace MailImporter {
 class FilterEvolution_v3Private;
+/**
+ * @brief The FilterEvolution_v3 class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class MAILIMPORTER_EXPORT FilterEvolution_v3 : public Filter
 {
 public:
     FilterEvolution_v3();
-    ~FilterEvolution_v3();
+    ~FilterEvolution_v3() override;
 
     void import() override;
     void importMails(const QString &maildir);
-    static QString defaultSettingsPath();
-    static QString isMailerFound();
+    Q_REQUIRED_RESULT static QString defaultSettingsPath();
+    Q_REQUIRED_RESULT static QString isMailerFound();
 
 private:
     void importDirContents(const QString &);
