@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,17 +21,21 @@
 
 #include "filterthunderbird.h"
 namespace MailImporter {
+/**
+ * @brief The FilterIcedove class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class MAILIMPORTER_EXPORT FilterIcedove : public FilterThunderbird
 {
 public:
     FilterIcedove();
-    ~FilterIcedove();
+    ~FilterIcedove() override;
 
-    static QString defaultSettingsPath();
-    static QString isMailerFound();
+    Q_REQUIRED_RESULT static QString defaultSettingsPath();
+    Q_REQUIRED_RESULT static QString isMailerFound();
 protected:
-    QString defaultInstallFolder() const override;
-    QString settingsPath() override;
+    Q_REQUIRED_RESULT QString defaultInstallFolder() const override;
+    Q_REQUIRED_RESULT QString settingsPath() override;
 };
 }
 
